<?php

function generate_excerpt_with_openai($title, $instructions, $api_key, $page_link)
{

    $content = "Create a concise and informative excerpt for a post/page titled '{$title}'. This is the page link '{$page_link}'. {$instructions}";

    $api_model = get_option('post_excerpt_api_model') != null ? get_option('post_excerpt_api_model') : 'gpt-3.5-turbo';

    $data = [
        'model' => $api_model, // or any other model
        'messages' => [['role' => 'user', 'content' => $content]],
        'temperature' => 0.7
    ];



    $args = array(
        'body'    => json_encode($data),
        'headers' => array(
            'Content-Type'  => 'application/json',
            'Authorization' => 'Bearer ' . $api_key
        )
    );

    $response = wp_remote_post('https://api.openai.com/v1/chat/completions', $args);

    // return $response;

    if (is_wp_error($response)) {
        // Handle error more specifically if needed
        return 0;
    }

    // return $response;
    $body = wp_remote_retrieve_body($response);
    $result = json_decode($body, true);

    // return $result;
    // Check for valid response
    if ($result['error']['message'] != null) {
        return array('status' => 2, 'message' => $result['error']['message']);
    }

    if (!isset($result['choices'][0]['message']['content'])) {
        return array('status' => 0, 'message' => 'Content not found.');
    } else {
        return array('status' => 1, 'message' =>  $result['choices'][0]['message']['content']);
    }
}


function generate_title_with_openai($title, $instructions, $api_key, $page_link, $post_excerpt)
{

    $content = "Generate a new title for a post originally titled '{$title}'. Here is the post link: '{$page_link}' and post exceprt: '{$post_excerpt}'. {$instructions}.";

    $api_model = get_option('post_excerpt_api_model') != null ? get_option('post_excerpt_api_model') : 'gpt-3.5-turbo';

    $data = [
        'model' => $api_model, // or any other model
        'messages' => [['role' => 'user', 'content' => $content]],
        'temperature' => 0.7
    ];



    $args = array(
        'body'    => json_encode($data),
        'headers' => array(
            'Content-Type'  => 'application/json',
            'Authorization' => 'Bearer ' . $api_key
        )
    );

    $response = wp_remote_post('https://api.openai.com/v1/chat/completions', $args);


    if (is_wp_error($response)) {
        // Handle error more specifically if needed
        return 0;
    }

    // return $response;
    $body = wp_remote_retrieve_body($response);
    $result = json_decode($body, true);
    // return $result;
    // Check for valid response
    if ($result['error']['message'] != null) {
        return array('status' => 2, 'message' => $result['error']['message']);
    }

    if (!isset($result['choices'][0]['message']['content'])) {
        return array('status' => 0, 'message' => 'Content not found.');
    } else {
        return array('status' => 1, 'message' =>  $result['choices'][0]['message']['content']);
    }
}



function post_excerpt_api_settings_page()
{


    if (isset($_POST['post_excerpt_settings_submit'])) {

        if (isset($_POST['post_excerpt_api_key'])) {
            $api_key = sanitize_text_field($_POST['post_excerpt_api_key']);
            update_option('post_excerpt_api_key', $api_key);
        }
        if (isset($_POST['extra_instructions'])) {
            $api_key = sanitize_text_field($_POST['extra_instructions']);
            update_option('extra_instructions', $api_key);
        }
        if (isset($_POST['post_excerpt_api_model'])) {
            $post_excerpt_api_model = sanitize_text_field($_POST['post_excerpt_api_model']);
            update_option('post_excerpt_api_model', $post_excerpt_api_model);
        }
        if (isset($_POST['extra_instructions_for_title'])) {
            $extra_instructions_for_title = sanitize_text_field($_POST['extra_instructions_for_title']);
            update_option('extra_instructions_for_title', $extra_instructions_for_title);
        }

        if (isset($_POST['auto_meta_pages'])) {
            update_option('auto_meta_pages', 1);
        } else {
            update_option('auto_meta_pages', 0);
        }

        if (isset($_POST['auto_meta_posts'])) {
            update_option('auto_meta_posts', 1);
        } else {
            update_option('auto_meta_posts', 0);
        }
    }


    // Retrieve the saved API key

    $api_key = get_option('post_excerpt_api_key');
    $extra_instructions = get_option('extra_instructions');
    $extra_instructions_for_title = get_option('extra_instructions_for_title');
    $api_model = get_option('post_excerpt_api_model');


    $user_id = get_current_user_id();

    $license_details = get_user_meta($user_id, 'user_license_details', true);

    if ($license_details) {
        $license_email = isset($license_details['email']) ? $license_details['email'] : '';
        $license_key = isset($license_details['key']) ? $license_details['key'] : '';
        $license_status = isset($license_details['status']) ? $license_details['status'] : '';
    } else {
        $license_email = '';
        $license_key = '';
        $license_status = '';
    }

    // delete_user_meta($user_id, 'user_license_details');

    // Display the settings page HTML
?>
    <div class="wrap">
        <h2> Settings</h2>
        <form method="post" action="">

            <table class="form-table">
                <tbody>


                    <tr>
                        <th scope="row" width="20%">License Key</th>
                        <td width="80%">
                            <input type="email" style="width: 500px; margin-top: 3px" id="post_excerpt_license_email"
                                name="post_excerpt_license_email" placeholder="Enter your license email"
                                value="<?php echo esc_attr($license_email); ?>">
                            <br>
                            <input type="text" style="width: 500px; margin-top: 3px" id="post_excerpt_license_key"
                                name="post_excerpt_license_key" placeholder="Enter your license key"
                                value="<?php echo esc_attr($license_key); ?>">
                            <br>
                            <span id="license_status" class="" style="margin-top: 3px; color: <?php echo ($license_status === 'active') ? 'green' : 'red'; ?>">
                                <?php echo ($license_status === 'active') ? 'Active' : 'Inactive'; ?>
                            </span> <br>
                            <?php if ($license_status !== 'active') : ?>
                                <button type="button" id="check_license_button" class="button button-primary" style="margin-top: 3px">
                                    Check License
                                </button>
                               <br> <a href="https://bulkmeta.com/pricing" target="_blank" >Purchase License</a>
                            <?php endif; ?>

                            <br />
                            <span id="license_check_result"></span>
                        </td>
                    </tr>


                    <tr>
                        <th scope="row" width="20%">OpenAI Api Key</th>
                        <td width="80%"> <input type="text" style="width: 500px;" id="post_excerpt_api_key" name="post_excerpt_api_key" value="<?php echo esc_attr($api_key); ?>">
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">OpenAI Api Model </th>
                        <td> <input type="text" style="width: 500px;" id="post_excerpt_api_model" name="post_excerpt_api_model" value="<?php echo esc_attr($api_model); ?>">
                            <br /> <a href="https://platform.openai.com/docs/models" target="_blank">Models List</a>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">Extra Instructions For Excerpts</th>
                        <td><textarea name="extra_instructions" style="width: 500px;" rows="5" cols="40"><?php echo esc_attr($extra_instructions); ?></textarea></td>
                    </tr>
                    <tr>
                        <th scope="row">Extra Instructions For Titles</th>
                        <td><textarea name="extra_instructions_for_title" style="width: 500px;" rows="5" cols="40"><?php echo esc_attr($extra_instructions_for_title); ?></textarea></td>
                    </tr>

                    <tr>
                        <th scope="row">Enable Auto Meta Description for Pages</th>
                        <td>
                            <input type="checkbox" id="auto_meta_pages" name="auto_meta_pages" value="1" <?php checked(1, get_option('auto_meta_pages'), true); ?>>
                            <label for="auto_meta_pages">Enable automatic meta descriptions for new pages</label>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">Enable Auto Meta Description for Posts</th>
                        <td>
                            <input type="checkbox" id="auto_meta_posts" name="auto_meta_posts" value="1" <?php checked(1, get_option('auto_meta_posts'), true); ?>>
                            <label for="auto_meta_posts">Enable automatic meta descriptions for new posts</label>
                        </td>
                    </tr>
                </tbody>
            </table>

            <!-- 
            <label for="post_excerpt_api_key">API Key:</label>
            <input type="text" style="width: 500px;" id="post_excerpt_api_key" name="post_excerpt_api_key" value="<?php echo esc_attr($api_key); ?>">
            <p>Enter your API key here.</p> -->
            <input type="submit" name="post_excerpt_settings_submit" class="button-primary" value="Save Settings">
        </form>
    </div>
<?php
}
