<?php

add_action('wp_ajax_update_post_excerpts', 'update_post_excerpts_callback_this_function');

function update_post_excerpts_callback_this_function()
{

    if (check_ajax_referer('update_post_excerpts_nonce', 'nonce', false)) {
        if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['selected_pages'])) {
            // Retrieve the API key
            $api_key = get_option('post_excerpt_api_key');
            $extra_instructions = get_option('extra_instructions');

            // Check if API Key is available
            if (empty($api_key)) {
                echo json_encode(array('error' => true, 'message' => 'OpenAI API key is missing.'));
                wp_die();
            }
            // echo json_encode(array('success' => true, 'message' => $api_key));

            // Process the selected pages and extra instructions
            if (!empty($_POST['selected_pages'])) {
                $selected_pages = $_POST['selected_pages'];



                foreach ($selected_pages as $page_id) {
                    $page = get_post($page_id);

                    if (!$page) {
                        continue;
                    }

                    $page_link = get_permalink($page_id);

                    $generated_excerpt = generate_excerpt_with_openai($page->post_title, $extra_instructions, $api_key, $page_link);

                    if ($generated_excerpt['status'] == 1) {
                        // Assuming the 'message' contains the excerpt you want to use

                        $except_without_quotes = str_replace('"', '', $generated_excerpt['message']);

                        wp_update_post([
                            'ID'           => $page_id,
                            'post_excerpt' => $except_without_quotes,
                        ]);

                        wp_send_json_success(['message' => 'Excerpt generated successfully!']);
                    } else {
                        // Handle different types of errors based on the 'status' code
                        // For now, we will send a generic error message, but you could customize this
                        wp_send_json_error(['message' => isset($generated_excerpt['message']) ? $generated_excerpt['message'] : 'There is an issue in your API.']);
                    }
                    // echo "<pre>";
                    // print_r($generated_excerpt);
                    // echo "</pre>";
                    // if($generated_excerpt == null){
                    //     $generated_excerpt2 = generate_excerpt_with_openai($page->post_title, $extra_instructions, $api_key, $page_link);
                    //     echo json_encode(array('success' => true, 'message' => 'Excerpts updated successfully.'));
                    // }
                    // print_r($generated_excerpt);


                }
                // echo json_encode(array('success' => true, 'message' => 'Excerpts updated successfully.'));
            }
        }

        wp_die();
    } else {
        wp_send_json_error(['message' => 'Nonce verification failed.']);
    }
}
function custom_error_notice()
{
?>
    <div class="notice notice-error is-dismissible">
        <p>There was an error processing the response from your API.</p>
    </div>
<?php
}


add_action('wp_ajax_update_post_titles', 'update_post_titles_callback_this_function');

function update_post_titles_callback_this_function()
{

    if (check_ajax_referer('update_post_excerpts_nonce', 'nonce', false)) {
        if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['selected_pages'])) {
            // Retrieve the API key
            $api_key = get_option('post_excerpt_api_key');
            $extra_instructions = get_option('extra_instructions');

            // Check if API Key is available
            if (empty($api_key)) {
                echo json_encode(array('error' => true, 'message' => 'OpenAI API key is missing.'));
                wp_die();
            }
            // echo json_encode(array('success' => true, 'message' => $api_key));

            // Process the selected pages and extra instructions
            if (!empty($_POST['selected_pages'])) {
                $selected_pages = $_POST['selected_pages'];


                foreach ($selected_pages as $page_id) {
                    $page = get_post($page_id);
                    if (!$page) {
                        continue;
                    }

                    $page_link = get_permalink($page_id);

                    $extra_instructions_for_title = get_option('extra_instructions_for_title');


                    $generated_title = generate_title_with_openai($page->post_title, $extra_instructions_for_title, $api_key, $page_link, $page->post_excerpt);

                    if ($generated_title['status'] == 1) {
                        // Assuming the 'message' contains the excerpt you want to use
                        $title_without_quotes = str_replace('"', '', $generated_title['message']);

                        if ($title_without_quotes != '') {
                            wp_update_post([
                                'ID'           => $page_id,
                                'post_title'   => $title_without_quotes,
                            ]);
                            wp_send_json_success(['message' => 'Title Generate successful!']);
                        } else {
                            wp_send_json_error(['message' => 'There is an issue in your API.']);
                        }

                        wp_send_json_success(['message' => 'Excerpt generated successfully!']);
                    } else {
                        // Handle different types of errors based on the 'status' code
                        // For now, we will send a generic error message, but you could customize this
                        wp_send_json_error(['message' => isset($generated_title['message']) ? $generated_title['message'] : 'There is an issue in your API.']);
                    }
                }
                // echo json_encode(array('success' => true, 'message' => 'Excerpts updated successfully.'));
            }
        }

        wp_die();
    } else {
        wp_send_json_error(['message' => 'Nonce verification failed.']);
    }
}
function generate_auto_meta_description($post_id) {
    // Don't run on autosave, post revisions, or if the post is still in draft mode
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return;
    if (wp_is_post_revision($post_id)) return;
    if (get_post_status($post_id) !== 'publish') return;

    // Avoid infinite loop when updating post inside the save_post hook
    remove_action('save_post', 'generate_auto_meta_description');

    $post_type = get_post_type($post_id);

    if ($post_type == 'page' && get_option('auto_meta_pages')) {
        generate_post_excerpt_function($post_id);
    }

    if ($post_type == 'post' && get_option('auto_meta_posts')) {
        generate_post_excerpt_function($post_id);
    }

    // Re-add the save_post action after post update
    add_action('save_post', 'generate_auto_meta_description');
}
add_action('save_post', 'generate_auto_meta_description');

function generate_post_excerpt_function($post_id){
    $api_key = get_option('post_excerpt_api_key');
    $extra_instructions = get_option('extra_instructions');

    // Check if API Key is available
    if (empty($api_key)) {
        error_log('OpenAI API key is missing.');
        return; 
    }

    $post = get_post($post_id);
    if (!$post) return; 

    $page_link = get_permalink($post_id);
    $page_title = $post->post_title;

    // Generate the excerpt using your custom OpenAI function
    $generated_excerpt = generate_excerpt_with_openai($page_title, $extra_instructions, $api_key, $page_link);

    if (isset($generated_excerpt['status']) && $generated_excerpt['status'] == 1) {
        // Clean up the generated excerpt
        $excerpt_without_quotes = str_replace('"', '', $generated_excerpt['message']);

        // Update the post with the generated excerpt
        wp_update_post([
            'ID'           => $post_id,
            'post_excerpt' => $excerpt_without_quotes,
        ]);
    } else {
        // Log the error if OpenAI fails to generate an excerpt
        error_log('OpenAI Excerpt Generation Error: ' . (isset($generated_excerpt['message']) ? $generated_excerpt['message'] : 'Unknown error.'));
    }
}
