<?php

require_once POST_EXCERPT_PLUGIN_DIR . 'vendor/autoload.php';


add_action('wp_ajax_check_license_key', 'check_license_key');

function check_license_key()
{


    $license_key = isset($_POST['license_key']) ? sanitize_text_field($_POST['license_key']) : '';
    $license_email = isset($_POST['license_email']) ? sanitize_text_field($_POST['license_email']) : '';


    if (empty($license_key)) {
        wp_send_json_error('License key is required.');
    }
    if (empty($license_email)) {
        wp_send_json_error('License email is required.');
    }




    $client = new \Google_Client();
    $client->setApplicationName('Google Sheets API');
    $client->setScopes(Google\Service\Sheets::SPREADSHEETS);
    $credentials_path = POST_EXCERPT_PLUGIN_DIR . 'includes/credentials.json';
    if (!file_exists($credentials_path)) {
        throw new Exception('Credentials file not found: ' . $credentials_path);
    }
    $client->setAuthConfig($credentials_path);
    $client->setAccessType('offline');

    $service = new Google\Service\Sheets($client);

    $spreadsheetId = '13piS1CmkLOx13DF8vI8Sc2UQsIg7wba8kOLONqFs1Jc';

    $range = 'Sheet1';

    try {
        $response = $service->spreadsheets_values->get($spreadsheetId, $range);
        if ($response === null) {
            throw new Exception('Response from Google Sheets API is null.');
        }

        $values = $response->getValues();
        $foundMatch = false;
        // wp_send_json_success($license_email);
        // Check if the license key exists in the Google Sheet
        foreach ($values as $row) {

            if (isset($row[1]) && $row[1] === $license_email) {
                if (isset($row[2]) && $row[2] === $license_key) {

                    $user_id = get_current_user_id();
                    $license_details = array(
                        'email' => $license_email,
                        'key'   => $license_key,
                        'status' => 'active'
                    );
                    update_user_meta($user_id, 'user_license_details', $license_details);


                    wp_send_json_success('License is valid.');
                    $foundMatch = true;
                    break;
                } else {
                    wp_send_json_error('License key invalid.');
                    $foundMatch = true;
                    break;
                }
            }
        }

        if (!$foundMatch) {
            wp_send_json_error('License email not matched.');
        }
    } catch (Exception $e) {
        wp_send_json_error('Error fetching data from Google Sheets: ' . $e->getMessage());
    }



    // End AJAX
    wp_die();
}




// Schedule the cron event if it's not already scheduled
if (!wp_next_scheduled('check_license_key_with_cron_daily')) {
    wp_schedule_event(time(), 'daily', 'check_license_key_with_cron_daily');
}

// Function to be executed by the cron job
function check_license_key_with_cron_function()
{
    $users = get_users(array(
        'meta_key' => 'user_license_details',
        'meta_compare' => 'EXISTS'
    ));

    // Loop through each user
    foreach ($users as $user) {
        $user_id = $user->ID;
        $license_details = get_user_meta($user_id, 'user_license_details', true);

        if (!empty($license_details)) {
            $license_email = isset($license_details['email']) ? $license_details['email'] : '';
            $license_key = isset($license_details['key']) ? $license_details['key'] : '';

            if ($license_email && $license_key) {
                error_log('Checking license for user: ' . $license_email);

                $client = new \Google_Client();
                $client->setApplicationName('Google Sheets API');
                $client->setScopes(Google\Service\Sheets::SPREADSHEETS);
                $credentials_path = POST_EXCERPT_PLUGIN_DIR . 'includes/credentials.json';

                if (!file_exists($credentials_path)) {
                    error_log('Credentials file not found: ' . $credentials_path);
                    continue;
                }

                $client->setAuthConfig($credentials_path);
                $client->setAccessType('offline');
                $service = new Google\Service\Sheets($client);
                $spreadsheetId = '13piS1CmkLOx13DF8vI8Sc2UQsIg7wba8kOLONqFs1Jc';
                $range = 'Sheet1';

                try {
                    $response = $service->spreadsheets_values->get($spreadsheetId, $range);
                    if ($response === null) {
                        error_log('Response from Google Sheets API is null.');
                        continue;
                    }

                    $values = $response->getValues();

                    $is_valid = false;
                    foreach ($values as $row) {
                        if (isset($row[1]) && $row[1] === $license_email && isset($row[2]) && $row[2] === $license_key) {
                            $is_valid = true;
                            error_log('License is valid for user: ' . $license_email);
                        }
                    }

                    // If no valid license was found, delete the user meta
                    if (!$is_valid) {
                        delete_user_meta($user_id, 'user_license_details');
                        error_log('License is invalid or not found for user: ' . $license_email);
                    }
                } catch (Exception $e) {
                    error_log('Error fetching data from Google Sheets: ' . $e->getMessage());
                }
            }
        } else {
            error_log('No license details found for user ID: ' . $user_id);
        }
    }
}

// Hook the function to the scheduled event
add_action('check_license_key_with_cron_daily', 'check_license_key_with_cron_function');
