<?php
/*
Plugin Name: Bulk Meta Descriptions
Description: Automatically fill-in any missing page meta descriptions (page excerpts), and any missing post meta descriptions (post excerpts).  The plugin leverages the power of OpenAI's API to create missing meta descriptions in your Pages and Posts, at scale.
Version: 2.21
Author: Bosseo.com
*/

if (! defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

define('POST_EXCERPT_PLUGIN_DIR', plugin_dir_path(__FILE__));


require_once POST_EXCERPT_PLUGIN_DIR . 'includes/license-function.php';
require_once POST_EXCERPT_PLUGIN_DIR . 'includes/api-functions.php';
require_once POST_EXCERPT_PLUGIN_DIR . 'includes/post-excerpt.php';
require_once POST_EXCERPT_PLUGIN_DIR . 'includes/page-excerpt.php';
require_once POST_EXCERPT_PLUGIN_DIR . 'includes/data-submit.php';
require_once POST_EXCERPT_PLUGIN_DIR . 'includes/keywords.php';


// register_activation_hook(__FILE__, 'post_excerpt_plugin_activate');
// register_deactivation_hook(__FILE__, 'post_excerpt_plugin_deactivate');


function post_excerpt_plugin_init()
{
    wp_enqueue_script('custom-script-post-excerpt', plugin_dir_url(__FILE__) . 'assets/script.js', array('jquery'), '1.0', true);

    wp_enqueue_style('custom-style-post-excerpt', plugin_dir_url(__FILE__) . 'assets/style.css', array(), '1.0');

    wp_enqueue_script('dataTables-post-excerpt', plugin_dir_url(__FILE__) . 'assets/dataTables.min.js', array('jquery'), '1.13.7', true);
    wp_enqueue_style('dataTables-style-post-excerpt', plugin_dir_url(__FILE__) . 'assets/dataTables.min.css');
    wp_enqueue_style('font-awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css');
}
add_action('init', 'post_excerpt_plugin_init');

// function enqueue_dataTables_scripts() {
//     wp_enqueue_script('jquery');

// add_action('wp_enqueue_scripts', 'enqueue_dataTables_scripts');
add_filter('http_request_timeout', function ($timeout) {
    return 15; // Increase the timeout value (in seconds) as needed
});

add_action('admin_menu', 'post_excerpt_plugin_menu_this_plugin');

// Function to create the menu
function post_excerpt_plugin_menu_this_plugin()
{

    // Add the main menu page for "Post Excerpt Settings"
    add_menu_page(
        'Bulk Meta Post Settings',          // Page title
        'Bulk Meta Posts',                   // Menu title
        'manage_options',                 // Capability
        'my-plugin-post-excerpt-settings', // Menu slug
        'post_excerpt_settings_page_this_plugin' // Function to display the settings page
    );

    // Add a submenu for "Page Excerpt Settings" under the main menu
    add_submenu_page(
        'my-plugin-post-excerpt-settings', // Parent menu slug
        'Bulk Meta Page Settings',           // Page title
        'Bulk Meta Pages',                    // Menu title
        'manage_options',                  // Capability
        'my-plugin-page-excerpt-settings', // Submenu slug
        'page_excerpt_settings_page_this_plugin' // Function to display the submenu page
    );

    // Add a submenu for "Keywords Generator" under the main menu
    add_submenu_page(
        'my-plugin-post-excerpt-settings', // Parent menu slug
        'Keywords Settings',               // Page title
        'Keywords Generator',              // Menu title
        'manage_options',                  // Capability
        'my-plugin-keywords-excerpt-settings', // Submenu slug
        'keywords_settings_page_this_plugin' // Function to display the submenu page
    );

    // Add a submenu for "Settings" under the main menu
    add_submenu_page(
        'my-plugin-post-excerpt-settings', // Parent menu slug
        'Settings',                        // Page title
        'Settings',                        // Menu title
        'manage_options',                  // Capability
        'my-plugin-post-excerpt-api-settings', // Submenu slug
        'post_excerpt_api_settings_page'   // Function to display the settings page
    );
}

function add_upgrade_to_pro_link($links) {

    $user_id = get_current_user_id();
    $license_details = get_user_meta($user_id, 'user_license_details', true);

    // Check if license status is not set or not active
    if (empty($license_details)) {

        $pro_link = '<a href="https://bulkmeta.com/pricing" target="_blank" style="color: #d64e07; font-weight: bold;">Upgrade to PRO</a>';
        array_push($links, $pro_link);
    }

    return $links;
}

add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'add_upgrade_to_pro_link');